from setuptools import setup

setup(
    name='Flask-LoginManager',
    version='1.0.6',
    keywords=('flask', 'login', 'multi-role', 'permission'),
    description='Flask Login Manager that supports multi-role and permissions, inspired by Flask-Login',
    license='MIT',
    author='rain',
    author_email='rain@joymud.com',
    url='',
    platforms='flask',
    packages=['flask_loginmanager'],
    install_requires=['Flask']
)
